# -*- coding: iso-8859-1 -*-
# pylint: disable-msg=C0103,W0131,E0213,W0232,R0912,R0921,E0212
# pylint-version = 0.7.0
#
# Copyright 2005 Andr Malo or his licensors, as applicable
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
TestBase class, which provides project module mocks
"""
__author__    = "Andr Malo"
__docformat__ = "restructuredtext en"
__all__       = ['TestBase']

# global imports
from svnmailer_test import stdmock
Store = stdmock.Store


class TestBase(stdmock.TestBase):
    """ Provides project module mocks """

    def _mock_svnmailer_browser_base(self):
        """ svnmailer.browser._base mock """
        self.mock.mailer_browser_base = Store(
            urlpath = "/foo/bar",
            querykeys = [],
        )

        class ParsedQuery(object):
            def __init__(this, query):
                this._query = query
            def __contains__(this, key):
                return key in self.mock.mailer_browser_base.querykeys
            def remove(this, toremove):
                self.mock.result.extend([
                    'browser._base.ParsedQuery.remove', toremove
                ])

        class ParsedUrl(object):
            def __init__(this, url):
                this._url = url
                this.path = self.mock.mailer_browser_base.urlpath
                this.query = ParsedQuery('query')

        class BaseGenerator(object):
            _BASE_PATH = "BASE_PATH"
            _BASE_REVISION = "BASE_REVISION"
            _PATH = "PATH"
            _REVISION = "REVISION"

            def _createParsedUrl(this, url):
                self.mock.result.extend([
                    'browser._base.BaseGenerator._createParsedUrl', url
                ])
                return ParsedUrl(url)

        class Template(object):
            def __init__(this, **kwargs):
                if self.mock.error == 'browser.template.attr':
                    raise AttributeError()
                this._mocked = 'Template'
                this._templates = kwargs

            def fromTemplates(cls, base_url, templates):
                self.mock.result.extend([
                    'browser._base.Template.fromTemplates', base_url._url,
                    templates
                ])
                return cls()
            fromTemplates = classmethod(fromTemplates)

        return ('svnmailer.browser._base', {
            'BaseGenerator': BaseGenerator,
            'ParsedUrl'    : ParsedUrl,
            'Template'     : Template,
        })


    def _mock_svnmailer_config(self):
        """ svnmailer.config mock """
        class ConfigFileSettings(object):
            def __init__(this):
                this.runtime = Store()
                this.general = Store()
                this.groups = [Store()]

        return ('svnmailer.config', {
            'ConfigFileSettings': ConfigFileSettings,
        })


    def _mock_svnmailer_processes(self):
        """ svnmailer.processes mock """
        class Process(object):
            def __init__(this, *args, **kwargs):
                if self.mock.error == 'processes.ni':
                    raise NotImplementedError()
                self.mock.result.extend(['processes.Process', args, kwargs])
            def detach(cls, command):
                return cls(command, detach = True)
            detach = classmethod(detach)

        return ('svnmailer.processes', {
            'Process': Process,
        })


    def _mock_svnmailer_settings(self):
        """ svnmailer.settings mock """
        class Modes(object):
            commit = 'C'
            propchange = 'P'
            lock = 'L'
            unlock = 'U'

        return ('svnmailer.settings', {
            'MODES': Modes(),
        }, True)


    def _mock_svnmailer_settings_base(self):
        """ svnmailer.settings._base mock """
        class Error(Exception):
            def __init__(this, *args, **kwargs):
                Exception.__init__(this, *args, **kwargs)
                if args or kwargs:
                    self.mock.result.extend(['_base.Error', args, kwargs])

        class BaseMapper(object):
            pass

        class BaseSettings(object):
            pass

        class BaseConfig(object):
            def __init__(this, settingsobj):
                self.mock.result.extend(['BaseConfig', settingsobj])

        class BaseMember(object):
            def init(this):
                self.mock.result.append('BaseMember.init')

        class BasePremapMember(object):
            def init(this):
                self.mock.result.append('BasePremapMember.init')

        class BasePostmapMember(object):
            def init(this):
                self.mock.result.append('BasePostmapMember.init')

        return ('svnmailer.settings._base', {
            'Error': Error,
            'BaseMapper': BaseMapper,
            'BaseSettings': BaseSettings,
            'BaseConfig': BaseConfig,
            'BaseMember': BaseMember,
            'BasePremapMember': BasePremapMember,
            'BasePostmapMember': BasePostmapMember,
        })


    def _mock_svnmailer_settings_fileparser(self):
        """ svnmailer.settings._fileparser mock """
        class Error(Exception):
            pass

        return ('svnmailer.settings._fileparser', {
            'Error': Error,
        })


    def _mock_svnmailer_settings_typedstruct(self):
        """ svnmailer.settings._typedstruct mock """
        class Struct(object):
            pass

        class StructCreator(object):
            def __new__(klass, members, cls = None, aliases = None,
                        typemap = None, eqignore = None):
                cls = cls or Struct
                return (members, cls.__name__, aliases, typemap, eqignore)

        class Member(object):
            pass

        return ('svnmailer.settings._typedstruct', {
            'Struct': Struct,
            'StructCreator': StructCreator,
            'Member': Member,
        })


    def _mock_svnmailer_subversion(self):
        """ svnmailer.subversion mock """
        self.mock.mailer_subversion = Store(descriptor = {
            'ca' : {'state': 'A', 'isdir': False},
            'cad': {'state': 'A', 'isdir': True },
            'cd' : {'state': 'D', 'isdir': False},
            'cdd': {'state': 'D', 'isdir': True },
            'cc' : {'state': 'C', 'isdir': False},
            'ccd': {'state': 'C', 'isdir': True },
            'cm' : {'state': 'M', 'isdir': False},
            'cmd': {'state': 'M', 'isdir': True },
            'c1' : {'base_path': '/somepath', 'path': '/otherpath',
                'base_rev': 1}
        })

        class VersionedPathDescriptor(object):
            def __init__(this, revision, change):
                this.revision = revision
                this._change = self.mock.mailer_subversion.descriptor[change]
                this.path = this._change.get('path')
            def getBaseRevision(this):
                return this._change['base_rev']
            def getBasePath(this):
                return this._change['base_path']
            def getModifiedProperties(this):
                raise NotImplementedError()
            def isDirectory(this):
                return this._change['isdir']
            def isBinary(this):
                raise NotImplementedError()
            def hasPropertyChanges(this):
                raise NotImplementedError()
            def hasContentChanges(this):
                raise NotImplementedError()
            def wasDeleted(this):
                return this._change['state'] == 'D'
            def wasAdded(this):
                return this._change['state'] in ['A', 'C']
            def wasModified(this):
                return this._change['state'] not in ['A', 'D', 'C']
            def wasCopied(this):
                return this._change['state'] == 'C'

        class _Version(object):
            major = 1
            minor = 2
            patch = 3
            tag = ' (456789)'
            min_1_2 = True

        return ('svnmailer.subversion', {
            'VersionedPathDescriptor': VersionedPathDescriptor,
            'version': _Version(),
        })


    def _mock_svnmailer_util(self):
        """ svnmailer.util mock """
        self.mock.mailer_util = Store(terminal_width = 69)

        class SomeClass(object):
            _mocked = 'SomeClass'
            pass

        def loadDotted(name):
            self.mock.result.extend(['util.loadDotted', name])
            if name == 'some.class':
                return SomeClass
            raise ImportError()

        class Singleton(object):
            __singletoninstance__ = None
            def __new__(cls):
                if cls.__singletoninstance__ is None:
                    cls.__singletoninstance__ = object.__new__(cls)
                return cls.__singletoninstance__

        def substitute(template, params):
            self.mock.result.extend(['util.substitute', template, params])
            if template is None:
                return None
            return template % params

        class _Terminal(object):
            def getWidth(this):
                return self.mock.mailer_util.terminal_width

        class _LocaleFile(object):
            def fromLocale(this, name, encoding = None):
                if self.mock.error == 'util.filename':
                    raise UnicodeError()
                self.mock.result.extend(['fromLocale', name, encoding])
                return "unicode(%s, %s)" % (name, encoding)
            def toLocale(this, name, name_enc = None, locale_enc = None,
                         force = False):
                if self.mock.error == 'util.filename':
                    raise UnicodeError()
                self.mock.result.extend(['toLocale',
                    name, name_enc, locale_enc, force])
                return "locale(%s, %s)" % (name, locale_enc)

        class ReadOnlyDict(dict):
            pass

        def splitCommand(command):
            if self.mock.error == "util.splitCommand":
                raise ValueError()
            return command.split()

        return ('svnmailer.util', {
            'loadDotted'  : loadDotted,
            'Singleton'   : Singleton,
            'substitute'  : substitute,
            'terminal'    : _Terminal(),
            'filename'    : _LocaleFile(),
            'ReadOnlyDict': ReadOnlyDict,
            'splitCommand': splitCommand,
        })
