# -*- coding: iso-8859-1 -*-
# pylint: disable-msg=E0201,W0131,E0213,W0232,F0203,W0613
# pylint-version = 0.7.0
#
# Copyright 2005 Andr Malo or his licensors, as applicable
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
Testcases for svnmailer.settings._base

:var _tests: The test classes
:type _tests: ``list``
"""
__author__    = "Andr Malo"
__docformat__ = "restructuredtext en"
__all__       = ['getSuite']

from svnmailer_test import base
_tests = []


#### Test Bases                                     ####
########################################################
class TestBase(base.TestBase):
    """ Base class for settings._base tests """
    LOAD_MODULES = (('_base', 'svnmailer.settings._base'),)

    def getInitialMocks(self):
        """ Returns the initially mocked modules """
        return [
            self._mock_svnmailer_settings_typedstruct(),
        ]


#### Test Cases                                     ####
########################################################
class ErrorTestCase(TestBase):
    """ svnmailer.settings._base.Error """

    def test00general(self):
        """ Error is a public settings.Error """
        from svnmailer import settings
        expected = settings.Error
        result = self._base.Error

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failUnless(result.__name__ in self.public(self._base),
            "Is not public")

_tests.append(ErrorTestCase)


class NotSupportedErrorTestCase(TestBase):
    """ svnmailer.settings._base.NotSupportedError """

    def test00general(self):
        """ NotSupportedError is a public Error """
        expected = self._base.Error
        result = self._base.NotSupportedError

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failUnless(result.__name__ in self.public(self._base),
            "Is not public")

_tests.append(NotSupportedErrorTestCase)


class GroupSettingsContainerTestCase(TestBase):
    """ svnmailer.settings._base.GroupSettingsContainer """
    PREFIX = "GroupSettingsContainer"

    def test00general(self):
        """ GroupSettingsContainer is a public _typedstruct.Struct """
        expected = self.mock['svnmailer.settings._typedstruct'].Struct
        result = self._base.GroupSettingsContainer

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failUnless(result.__name__ in self.public(self._base),
            "Is not public")

_tests.append(GroupSettingsContainerTestCase)


class GeneralSettingsContainerTestCase(TestBase):
    """ svnmailer.settings._base.GeneralSettingsContainer """
    PREFIX = "GeneralSettingsContainer"

    def test00general(self):
        """ GeneralSettingsContainer is a public _typedstruct.Struct """
        expected = self.mock['svnmailer.settings._typedstruct'].Struct
        result = self._base.GeneralSettingsContainer

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failUnless(result.__name__ in self.public(self._base),
            "Is not public")

_tests.append(GeneralSettingsContainerTestCase)


class RuntimeSettingsContainerTestCase(TestBase):
    """ svnmailer.settings._base.RuntimeSettingsContainer """
    PREFIX = "RuntimeSettingsContainer"

    def test00general(self):
        """ RuntimeSettingsContainer is a public _typedstruct.Struct """
        expected = self.mock['svnmailer.settings._typedstruct'].Struct
        result = self._base.RuntimeSettingsContainer

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failUnless(result.__name__ in self.public(self._base),
            "Is not public")

_tests.append(RuntimeSettingsContainerTestCase)


class BaseSettingsTestCase(TestBase):
    """ svnmailer.settings._base.BaseSettings """
    PREFIX = "BaseSettings"

    def setUp(self):
        """ Extends the test environment """
        super(BaseSettingsTestCase, self).setUp()
        class Container(object):
            def __init__(this, **kwargs):
                this.__mocked__ = '*%s*' % this.__class__.__name__
                self.mock.result.extend([this.__class__.__name__, kwargs])

        class Creator(object):
            def __init__(this, name):
                this._name = name
            def create(this, **kwargs):
                self.mock.result.extend(['Creator.create', kwargs])
                return "struct(%s)" % this._name

        class GroupContainer(Container):
            pass
        class GeneralContainer(Container):
            pass
        class RuntimeContainer(Container):
            pass

        class MySettings(self._base.BaseSettings):
            _GROUP_CONTAINER = GroupContainer
            _GENERAL_CONTAINER = GeneralContainer
            _RUNTIME_CONTAINER = RuntimeContainer
            def __init__(this):
                this._maps     = '*maps*'
                this._charset  = '*charset*'
                this._fcharset = '*fcharset*'
                this._mappers  = '*mappers*'
                this._creators = {
                    'general': Creator('general'),
                    'group'  : Creator('group'),
                    'runtime': Creator('runtime'),
                }

        class MapFinder(object):
            def __init__(this, *args):
                this.__mocked__ = '*MapFinder*'
                self.mock.result.extend(['MapFinder', args])

        self._base.MapFinder = MapFinder
        self._mysettings = MySettings

    def test00general(self):
        """ BaseSettings is a public object """
        expected = object
        result = self._base.BaseSettings

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failUnless(result.__name__ in self.public(self._base),
            "Is not public")

    def test01initial(self):
        """ BaseSettings' class attributes are properly filled initially """
        cls = self._base.BaseSettings
        self.mock.result = [
            cls.MAPSECTION, cls.DEFAULTSECTION, cls.GENERALSECTION,
            cls._DEFAULT_CHARSET, cls._GROUP_CONTAINER, cls._GENERAL_CONTAINER,
            cls._RUNTIME_CONTAINER
        ]

        self.expect(
            u"maps", u"defaults", u"general",
            "us-ascii",
            self._base.GroupSettingsContainer,
            self._base.GeneralSettingsContainer,
            self._base.RuntimeSettingsContainer
        )

    def test02init(self):
        """ .__init__ sets default values and runs custom initializer """
        class MySettings(self._base.BaseSettings):
            _DEFAULT_CHARSET = "foo"
            def _createCreators(this, members, typemap):
                self.mock.result.extend(['_createCreators', members, typemap])
                return '*creators'
            def _initRuntime(this, options):
                self.mock.result.extend(['_initRuntime', options])
                return '*runtime'
            def init(this):
                self.mock.result.append('init')
                self.mock.result.extend([
                    this._charset, this._fcharset, this._maps, this._mappers,
                    this.groups, this.general, this.runtime
                ])
            def _checkInitialization(this):
                self.mock.result.append('_checkInitialization')
        class MyOptions(str):
            path_encoding = 'bar'
        options = MyOptions('*options')
        MySettings(options, '*members', '*typemap', '*mappers')

        self.expect(
            '_createCreators', '*members', '*typemap',
            '_initRuntime', '*options',
            'init', 'foo', 'bar', None, '*mappers', [], None, '*runtime',
            '_checkInitialization'
        )

    def test03init(self):
        """ .init is not implemented """
        self.failUnlessRaises(NotImplementedError, self._mysettings().init)

    def test04checkInitialization(self):
        """ ._checkinitialization raises AssertionError """
        tests = (
            (None, None, None),
            (1,    None, None),
            (None, 1,    None),
            (None, None, 1   ),
            (1,    1,    None),
            (1,    None, 1   ),
            (None, 1,    1   ),
        )
        inst = self._mysettings()
        for test in tests:
            inst.general, inst.runtime, inst.groups = test
            self.failUnlessRaises(AssertionError, inst._checkInitialization)

    def test05checkInitialization(self):
        """ ._checkInitialization passes if all settings are True """
        inst = self._mysettings()
        inst.general, inst.runtime, inst.groups = 1, 1, 1
        inst._checkInitialization()

    def test06initRuntime(self):
        """ ._initRuntime returns a newly created RuntimeSettingsContainer """
        class MySettings(self._mysettings):
            def _createRuntimeContainer(this, **kwargs):
                return kwargs
        options = base.Store(
            revision = 1, repository = 2, path_encoding = 3, debug = 4,
            config = 5, mode = 6, author = 7, propname = 8, action = 9
        )
        self.mock.result.append(MySettings()._initRuntime(options))

        self.expect({
            'repository': 2, 'author': 7, 'action': 9, 'mode': 6,
            'propname': 8, 'debug': 4, 'path_encoding': 3, 'config': 5,
            'revision': 1
        })

    def test07createGroupContainer(self):
        """ ._createGroupContainer returns a new group container """
        self.mock.result.append(
            self._mysettings()._createGroupContainer(foo = 'bar')
        )

        self.expect(
            'Creator.create', {'maps': '*maps*', 'initkw': {'foo': 'bar'},
                'arg': {'path_encoding': '*fcharset*',
                'encoding': '*charset*'}},
            'struct(group)'
        )

    def test08createDefaultGroupContainer(self):
        """ ._createDefaultGroupContainer returns a new group container """
        self.mock.result.append(
            self._mysettings()._createDefaultGroupContainer(bar = 'baz')
        )

        self.expect(
            'Creator.create', {'maps': None, 'initkw': {'bar': 'baz'},
                'arg': {'path_encoding': '*fcharset*',
                'encoding': '*charset*'}},
            'struct(group)'
        )

    def test09createGeneralContainer(self):
        """ ._createGeneralContainer returns a new general container """
        self.mock.result.append(
            self._mysettings()._createGeneralContainer(baz = 'zonk')
        )

        self.expect(
            'Creator.create', {'maps': '*maps*', 'initkw': {'baz': 'zonk'},
                'arg': {'path_encoding': '*fcharset*',
                'encoding': '*charset*'}},
            'struct(general)'
        )

    def test10createRuntimeContainer(self):
        """ ._createRuntimeContainer returns a new runtime container """
        self.mock.result.append(
            self._mysettings()._createRuntimeContainer(zonk = 'buh')
        )

        self.expect(
            'Creator.create', {'maps': None, 'initkw': {'zonk': 'buh'},
                'arg': {'path_encoding': '*fcharset*', 'encoding': 'utf-8'}},
            'struct(runtime)'
        )

    def test11createMapFinder(self):
        """ ._createMapFinder returns a new MapFinder """
        self.mock.result.append(
            self._mysettings()._createMapFinder('*config*').__mocked__
        )

        self.expect('MapFinder', ('*mappers*', '*config*'), '*MapFinder*')

    def test12createCreators(self):
        """ ._createCreators returns a dict with new container creators """
        members = {
            'group': {'members': '*group_members', 'aliases': '*group_aliases',
                'eqignore': '*group_eqignore'},
            'general': {'members': '*general_members',
                'aliases': '*general_aliases'},
            'runtime': {'members': '*runtime_members',
                'aliases': '*runtime_aliases'}
        }
        self.mock.result.append(
            self._mysettings()._createCreators(members, '*typemap*')
        )

        self.expect({
            'runtime': ('*runtime_members', 'RuntimeContainer',
                '*runtime_aliases', '*typemap*', None),
            'group': ('*group_members', 'GroupContainer',
                '*group_aliases', '*typemap*', '*group_eqignore'),
            'general': ('*general_members', 'GeneralContainer',
                '*general_aliases', '*typemap*', None)
        })

_tests.append(BaseSettingsTestCase)


class MapFinderTestCase(TestBase):
    """ svnmailer.settings._base.MapFinder """
    PREFIX = "MapFinder"

    def setUp(self):
        """ Extends the test environment """
        super(MapFinderTestCase, self).setUp()
        class BaseMapper(object):
            def __init__(this, config, _show = True):
                this.__mocked__ = '*%s*' % this.__class__.__name__
                if _show:
                    self.mock.result.extend([this.__class__.__name__, config])
            def create(this, spec):
                self.mock.result.extend(['create', spec])
                if spec == this.__class__.__name__:
                    return 'mapper:%s' % spec
                return None

            def cleanup(this):
                self.mock.result.append('%s.cleanup' % this.__class__.__name__)

        class Mapper1(BaseMapper):
            pass
        class Mapper2(BaseMapper):
            pass

        self._mappers = (Mapper1, Mapper2)

        class MyFinder(self._base.MapFinder):
            def __init__(this):
                config = '*config*'
                this._mappers = [
                    mapper(config, False) for mapper in self._mappers
                ]

        self._myfinder = MyFinder

    def test00general(self):
        """ MapFinder is a public object """
        expected = object
        result = self._base.MapFinder

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failUnless(result.__name__ in self.public(self._base),
            "Is not public")

    def test01init(self):
        """ .__init__ initializes ._mappers """
        inst = self._base.MapFinder(self._mappers, '*config*')
        self.mock.result.extend([
            mapper.__mocked__ for mapper in inst._mappers
        ])

        self.expect(
            'Mapper1', '*config*',
            'Mapper2', '*config*',
            '*Mapper1*', '*Mapper2*'
        )

    def test02find(self):
        """ .find returns the first mapper """
        inst = self._myfinder()
        self.mock.result.append(inst.find('Mapper1'))

        self.expect('create', 'Mapper1', 'mapper:Mapper1')

    def test03find(self):
        """ .find returns the second mapper """
        inst = self._myfinder()
        self.mock.result.append(inst.find('Mapper2'))

        self.expect('create', 'Mapper2', 'create', 'Mapper2', 'mapper:Mapper2')

    def test04find(self):
        """ .find returns no mapper """
        inst = self._myfinder()
        self.mock.result.append(inst.find('Mapper3'))

        self.expect('create', 'Mapper3', 'create', 'Mapper3', None)

    def test05cleanup(self):
        """ .cleanup runs cleanup methods of all mappers """
        self._myfinder().cleanup()

        self.expect('Mapper1.cleanup', 'Mapper2.cleanup')

_tests.append(MapFinderTestCase)


class BaseMapperTestCase(TestBase):
    """ svnmailer.settings._base.BaseMapper """
    PREFIX = "BaseMapper"

    def setUp(self):
        """ Extends the test environment """
        super(BaseMapperTestCase, self).setUp()
        class MyMapper(self._base.BaseMapper):
            def __init__(this):
                pass

        self._mymapper = MyMapper

    def test00general(self):
        """ BaseMapper is a public object """
        expected = object
        result = self._base.BaseMapper

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failUnless(result.__name__ in self.public(self._base),
            "Is not public")

    def test01init(self):
        """ .__init__ initializes ._config and runs .init() """
        class MyMapper(self._base.BaseMapper):
            def init(this):
                self.mock.result.extend(['init', this._config])
        self.mock.result.append(MyMapper('*config*')._config)

        self.expect('init', '*config*', '*config*')

    def test02init(self):
        """ .init is implemented """
        self._mymapper().init()

    def test03create(self):
        """ .create is not implemented """
        self.failUnlessRaises(NotImplementedError,
            self._mymapper().create, '*spec*')

    def test04cleanup(self):
        """ .cleanup is implemented """
        self._mymapper().cleanup()

_tests.append(BaseMapperTestCase)


class BaseConfigTestCase(TestBase):
    """ svnmailer.settings._base.BaseConfig """
    PREFIX = "BaseConfig"

    def setUp(self):
        """ Extends the test environment """
        super(BaseConfigTestCase, self).setUp()
        class MyConfig(self._base.BaseConfig):
            def __init__(this):
                pass

        self._myconfig = MyConfig

    def test00general(self):
        """ BaseConfig is a public object """
        expected = object
        result = self._base.BaseConfig

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failUnless(result.__name__ in self.public(self._base),
            "Is not public")

    def test01init(self):
        """ .__init__ intializes the charset from supplied settings """
        settings = base.Store(_charset = 'foo')
        inst = self._base.BaseConfig(settings)
        self.mock.result.append(inst.charset)

        self.expect('foo')

    def test02iter(self):
        """ .__iter__ is not implemented """
        self.failUnlessRaises(NotImplementedError,
            self._myconfig().__iter__)

    def test03delitem(self):
        """ .__delitem__ is not implemented """
        self.failUnlessRaises(NotImplementedError,
            self._myconfig().__delitem__, '*section*')

    def test04extractSection(self):
        """ .extractSection is not implemented """
        self.failUnlessRaises(NotImplementedError,
            self._myconfig().extractSection, '*section*')
        self.failUnlessRaises(NotImplementedError,
            self._myconfig().extractSection, '*section*', xform = False)
        self.failUnlessRaises(NotImplementedError,
            self._myconfig().extractSection, '*section*', keep = True)
        self.failUnlessRaises(NotImplementedError,
            self._myconfig().extractSection, '*section*', check = False)

_tests.append(BaseConfigTestCase)


class BaseMemberTestCase(TestBase):
    """ svnmailer.settings._base.BaseMember """
    PREFIX = "BaseMember"

    def setUp(self):
        """ Extends the test environment """
        super(BaseMemberTestCase, self).setUp()
        class MyDescriptor(self._base.BaseMember):
            def __init__(this, param = None, arg = None):
                this.param = param
                this.arg = arg

        self._mydescriptor = MyDescriptor

    def test00general(self):
        """ BaseMember is a public _typedstruct.Member """
        expected = self.mock['svnmailer.settings._typedstruct'].Member
        result = self._base.BaseMember

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failUnless(result.__name__ in self.public(self._base),
            "Is not public")

    def test01init(self):
        """ .init initializes the instance attributes from None """
        inst = self._mydescriptor()
        inst.init()
        self.mock.result = [
            inst.param, inst.MAP, inst.SUBST, inst.CHARSET, inst.FILECHARSET
        ]

        self.expect({}, False, False, 'us-ascii', None)

    def test02init(self):
        """ .init initializes the instance attributes from param and arg """
        inst = self._mydescriptor(
            param = {'map': True, 'subst': False},
            arg = {'encoding': 'foo', 'path_encoding': 'bar'}
        )
        inst.init()
        self.mock.result = [
            inst.param, inst.MAP, inst.SUBST, inst.CHARSET, inst.FILECHARSET
        ]
        inst = self._mydescriptor(param = {'map': False, 'subst': True})
        inst.init()
        self.mock.result.extend([inst.MAP, inst.SUBST])

        self.expect(
            {'map': True, 'subst': False}, True, False, 'foo', 'bar',
            False, True
        )

    def test03transform(self):
        """ .transform passes None """
        class MyDescriptor(self._mydescriptor):
            def doTransform(this, value):
                self.fail("doTransform called")
        inst = MyDescriptor()
        self.mock.result.append(inst.transform(None))

        self.expect(None)

    def test04transform(self):
        """ .transform transforms non-None """
        class MyDescriptor(self._mydescriptor):
            def doTransform(this, value):
                self.mock.result.extend(['doTransform', value])
                return "transformed(%s)" % value
        inst = MyDescriptor()
        self.mock.result.append(inst.transform('foo'))

        self.expect('doTransform', 'foo', 'transformed(foo)')

    def test05substitute(self):
        """ .substitute passes None """
        class MyDescriptor(self._mydescriptor):
            def doSubstitute(this, value, subst):
                self.fail("doSubstitute called")
        inst = MyDescriptor()
        inst.SUBST = True
        self.mock.result.append(inst.substitute(None, {'x': 'y'}))
        inst.SUBST = False
        self.mock.result.append(inst.substitute(None, {'x': 'y'}))

        self.expect(None, None)

    def test06substitute(self):
        """ .substitute substitutes the value based on .SUBST """
        class MyDescriptor(self._mydescriptor):
            def doSubstitute(this, value, subst):
                self.mock.result.extend(['doSubstitute', value, subst])
                return "substituted(%s)" % value
        inst = MyDescriptor()
        inst.SUBST = True
        self.mock.result.append(inst.substitute('foo', {'x': 'y'}))
        inst.SUBST = False
        self.mock.result.append(inst.substitute('bar', {'x': 'y'}))

        self.expect(
            'doSubstitute', 'foo', {'x': 'y'},
            'substituted(foo)',
            'bar'
        )

    def test07premap(self):
        """ .premap passes None """
        class MyDescriptor(self._mydescriptor):
            def doPremap(this, value):
                self.fail("doPremap called")
        inst = MyDescriptor()
        inst.MAP = True
        self.mock.result.append(inst.premap(None))
        inst.MAP = False
        self.mock.result.append(inst.premap(None))

        self.expect(None, None)

    def test08premap(self):
        """ .premap maps the value based on .MAP """
        class MyDescriptor(self._mydescriptor):
            def doPremap(this, value):
                self.mock.result.extend(['doPremap', value])
                return "premapped(%s)" % value
        inst = MyDescriptor()
        inst.MAP = True
        self.mock.result.append(inst.premap('foo'))
        inst.MAP = False
        self.mock.result.append(inst.premap('bar'))

        self.expect('doPremap', 'foo', 'premapped(foo)', 'bar')

    def test09postmap(self):
        """ .postmap passes None """
        class MyDescriptor(self._mydescriptor):
            def doPostmap(this, value):
                self.fail("doPostmap called")
        inst = MyDescriptor()
        inst.MAP = True
        self.mock.result.append(inst.postmap(None))
        inst.MAP = False
        self.mock.result.append(inst.postmap(None))

        self.expect(None, None)

    def test10postmap(self):
        """ .postmap maps the value based on .MAP """
        class MyDescriptor(self._mydescriptor):
            def doPostmap(this, value):
                self.mock.result.extend(['doPostmap', value])
                return "postmapped(%s)" % value
        inst = MyDescriptor()
        inst.MAP = True
        self.mock.result.append(inst.postmap('foo'))
        inst.MAP = False
        self.mock.result.append(inst.postmap('bar'))

        self.expect('doPostmap', 'foo', 'postmapped(foo)', 'bar')

    def test11doPremap(self):
        """ .doPremap is not supported by default """
        self.failUnlessRaises(self._base.NotSupportedError,
            self._mydescriptor().doPremap, 'foo')

    def test12doTransform(self):
        """ .doTransform is not supported by default """
        self.failUnlessRaises(self._base.NotSupportedError,
            self._mydescriptor().doTransform, 'foo')

    def test13doSubstitute(self):
        """ .doSubstitute is not supported by default """
        self.failUnlessRaises(self._base.NotSupportedError,
            self._mydescriptor().doSubstitute, 'foo', {'x': 'y'})

    def test14doPostmap(self):
        """ .doPostmap is not supported by default """
        self.failUnlessRaises(self._base.NotSupportedError,
            self._mydescriptor().doPostmap, 'foo')

_tests.append(BaseMemberTestCase)


class BasePremapMemberTestCase(TestBase):
    """ svnmailer.settings._base.BasePremapMember """
    PREFIX = "BasePremapMember"

    def test00general(self):
        """ BasePremapMember is a public BaseMember """
        expected = self._base.BaseMember
        result = self._base.BasePremapMember

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failUnless(result.__name__ in self.public(self._base),
            "Is not public")

    def test01doPremap(self):
        """ .doPremap implements a default premapper """
        inst = self._base.BasePremapMember()
        def mapper(value):
            return 'mapped(%s)' % value
        inst.mapper = mapper
        self.mock.result.append(inst.doPremap('foo'))

        self.expect('mapped(foo)')

    def test02doPostmap(self):
        """ .doPostmap implements a pass through postmapper """
        inst = self._base.BasePremapMember()
        self.mock.result.append(inst.doPostmap('bar'))

        self.expect('bar')

_tests.append(BasePremapMemberTestCase)


class BasePostmapMemberTestCase(TestBase):
    """ svnmailer.settings._base.BasePostmapMember """
    PREFIX = "BasePostmapMember"

    def test00general(self):
        """ BasePostmapMember is a public BaseMember """
        expected = self._base.BaseMember
        result = self._base.BasePostmapMember

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failUnless(result.__name__ in self.public(self._base),
            "Is not public")

    def test01doPremap(self):
        """ .doPremap implements a pass through premapper """
        inst = self._base.BasePostmapMember()
        self.mock.result.append(inst.doPremap('baz'))

        self.expect('baz')

    def test02doPostmap(self):
        """ .doPostmap is not supported by default """
        self.failUnlessRaises(self._base.NotSupportedError,
            self._base.BasePostmapMember().doPostmap, 'zonk')

_tests.append(BasePostmapMemberTestCase)


#### Glue code                                      ####
########################################################
__all__.extend(_tests)

def getSuite():
    """ Returns the test suite for this module """
    return [_test.__name__ for _test in _tests]
